\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{thesistemplate}[2017/01/01 MUET M.E. Thesis Class File]

\PassOptionsToClass{a4paper,12pt}{report}
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{report}}
\ProcessOptions \relax

\LoadClass[a4paper,12pt]{report}

\RequirePackage{geometry}
\geometry{a4paper,left=1.5in,top=1.5in,right=1in,bottom=1in,headheight=13.6pt,includefoot,footskip=\dimexpr\headsep+\ht\strutbox\relax}
\RequirePackage[pdfborder={0 0 0},colorlinks=false,breaklinks=true]{hyperref}
\RequirePackage{ifpdf}
\ifpdf
\RequirePackage[pdftex]{graphicx,color}
\else
\RequirePackage{graphicx,color}
\fi
\RequirePackage[font=small,labelfont=bf,textfont=bf,singlelinecheck=off,format=hang,justification=centering]{caption}
\RequirePackage[font=small,labelfont=bf,textfont=bf,singlelinecheck=off,format=hang,justification=centering]{subcaption}
\RequirePackage{amsmath,amssymb,amsthm,array}
\RequirePackage[titletoc,title]{appendix}
\RequirePackage{abstract}
\RequirePackage[overload]{textcase}
\RequirePackage[explicit]{titlesec}
\RequirePackage{sectsty}
\RequirePackage[normalem]{ulem}
\RequirePackage{setspace}
\RequirePackage{alltt}
\RequirePackage{xifthen}
\RequirePackage{enumitem}

\setcounter{secnumdepth}{3}
\setlength\itemsep{0pt}

\partfont{\LARGE\centering\MakeTextUppercase}
\titleformat{\chapter}[display]
{\normalfont\large\bfseries\centering}{\uline{\MakeUppercase \chaptertitlename\ \thechapter}}{0pt}{\uline{\MakeUppercase{#1}}}
\titlespacing*{\chapter}{0pt}{-50pt}{40pt}
\sectionfont{\normalsize\MakeTextUppercase}
\subsectionfont{\normalsize}

% \partfont{\LARGE\centering\MakeTextUppercase}
% \chapterfont{\Large\centering\MakeTextUppercase}
% \chaptertitlefont{\Large\centering\MakeTextUppercase}
% \sectionfont{\large\MakeTextUppercase}
% \subsectionfont{\large}

\setlength{\abovecaptionskip}{6pt}
\setlength{\belowcaptionskip}{6pt}

\renewcommand{\arraystretch}{1.3}

\renewcommand{\bibname}{References}
\renewcommand{\contentsname}{Table of Contents}
\addtocontents{toc}{\protect{\pdfbookmark[0]{\contentsname}{toc}}}

% \renewcommand{\abstractnamefont}{\Large\bfseries\MakeTextUppercase}
% \renewcommand{\abstracttextfont}{\normalfont}

\newcommand\@logo{}
\newcommand\logo[1]{\renewcommand\@logo{#1}}

\newif\if@supervisor  \@supervisorfalse
\def\supervisor#1{\gdef\@supervisor{#1}\@supervisortrue}

\newif\if@cosupervisor  \@cosupervisorfalse
\def\cosupervisor#1{\gdef\@cosupervisor{#1}\@cosupervisortrue}

\newif\if@acknowledgement  \@acknowledgementfalse
\def\acknowledgement#1{\gdef\@acknowledgement{#1}\@acknowledgementtrue}

\newif\if@program  \@programfalse
\def\program#1{\gdef\@program{#1}\@programtrue}

% \renewcommand*{\thefootnote}{\fnsymbol{footnote}}

\makeatletter
\renewcommand{\maketitle}{%
  \let\footnotesize\small
%   \let\footnoterule\relax
%   \let\footnote\thanks
  \begin{center}
    \LARGE{\textbf{\MakeUppercase \@title}}  \\ \vspace{1cm}
    \@logo \\ \vspace{1cm}
    \large{A thesis submitted by \\[1.5ex] \textbf{\@author}} \\ \vspace{1.8cm}
    \ifx\@cosupervisor\@empty 
     \begin{tabular*}{\textwidth}{c @{\extracolsep{\fill}} cc}
     & \textbf{Supervisor} & \\
     & \@supervisor & \\[1.8cm]
     \end{tabular*}
    \else
     \begin{tabular*}{\textwidth}{c @{\extracolsep{\fill}} cc}
     \textbf{Supervisor} &  & \textbf{Co-Supervisor} \\
     \@supervisor &  & \@cosupervisor \\[1.8cm]
     \end{tabular*}
    \fi
    \large{In the partial fulfillment of the requirements for the degree of \\ Master of Engineering in \@program} \\ \vspace{1.3cm}
    \large{Faculty of Electrical, Electronics \& Computer Engineering} \\[2ex]
    \large{MEHRAN UNIVERSITY OF ENGINEERING \& TECHNOLOGY, JAMSHORO} \\ \vspace{1cm}
    \large{\@date}
  \end{center}
  \par
  \@thanks
  \vfill\null\setcounter{footnote}{0}
  \thispagestyle{empty}\addtocounter{page}{-1}
  \newpage
  \begin{center}
    \large{\textbf{\MakeUppercase{Mehran University of Engineering \& Technology, Jamshoro}}}  \\ \vspace{0.5cm}
  \end{center}
  \large{This thesis, written by ``\textbf{\@author}'' under the directions of the \emph{\@supervisor} (supervisor), \ifx\@cosupervisor\@empty \else \emph{\@cosupervisor} (co-supervisor), \fi and approved by all the members of the thesis committee, has been presented to and accepted by the Dean, Faculty of Electrical, Electronics \& Computer Engineering, in partial fulfilment of the requirements for the degree of Master of Engineering in \@program.} \\[6ex]
  \begin{center}
  \begin{tabular*}{\textwidth}{@{\extracolsep{\fill}}ccc@{\extracolsep{\fill}}}
  \rule{0.3\textwidth}{0.4pt} & \rule{0.3\textwidth}{0.4pt} & \rule{0.3\textwidth}{0.4pt} \\
  (Supervisor) & (Internal Examiner) & (External Examiner) \\[12ex]
  \end{tabular*}
  \begin{tabular*}{\textwidth}{c @{\extracolsep{\fill}} cc}
  \rule{0.3\textwidth}{0.4pt} &  & \rule{0.3\textwidth}{0.4pt} \\
  (Director, Postgraduate Studies) &  & (Dean, FEECE) \\[4ex]
  \end{tabular*}
  \end{center}
  \vspace{2cm}
  Date: \rule{0.2\textwidth}{0.4pt}
  \thispagestyle{empty}\addtocounter{page}{-1}
  \ifx\@acknowledgement\@empty
  \else
   \newpage
   \begin{center}
     \large{\textbf{\uline{\MakeUppercase{Acknowledgement}}}}  \\ \vspace{1cm}
   \end{center}
   \large{\@acknowledgement}
  \fi
}
\makeatother

% \makeatletter
% \renewenvironment{abstract}{%
%   \newpage
%     \begin{center}
%       \large{\textbf{\uline{\MakeUppercase{\abstractname}}}} \\ \vspace{1cm}
%     \end{center}}
% \makeatother

% \newpagestyle{main}{\sethead{}{}{\thepage}}
% \pagestyle{main}
% \newpagestyle{chapterpage}{\setfoot{}{\thepage}{}}
% \assignpagestyle\chapter{chapterpage}


